@@ -193,9 +193,12 @@ class FakePairing(AbstractPairing):
 
         class MockConnection(HomeKitConnection):
             @property
-            def is_connected(self):
+            def is_connected(self) -> bool:
                 raise ValueError("This attribute is removed")
 
+            def reconnect_soon(self) -> None:
+                pass
+
         self.connection = MockConnection(None, "fake_host", 1234)
         self.connection.transport = "mock_transport"
         self.connection.protocol = "mock_protocol"
